==> provenance_3.0.tar.gz: provenance/README.md <==
# provenance

**provenance** bundles a number of established statistical methods to
  facilitate the visual interpretation of large datasets in
  sedimentary geology. Includes functionality for adaptive kernel
  density estimation, principal component analysis, correspondence
  analysis, multidimensional scaling, generalised procrustes analysis
  and individual differences scaling using a variety of dissimilarity
  measures. Univariate provenance proxies, such as single-grain ages
  or (isotopic) compositions are compared with the Kolmogorov-Smirnov,
  Kuiper or Sircombe-Hazelton L2 distances. Categorical provenance
  proxies such as chemical compositions are compared with the
  Aitchison and Bray-Curtis distances, and point-counting data with
  the chi-square distance. Also included are tools to plot
  compositional and point-counting data on ternary diagrams and
  point-counting data on radial plots, to calculate the sample size
  required for specified levels of statistical precision, and to
  assess the effects of hydraulic sorting on detrital
  compositions. Includes an intuitive query-based user interface for
  users who are not proficient in R..

## Prerequisites

You must have **R** installed on your system (see
[https://www.r-project.org](https://www.r-project.org)).  Additionally, to
install provenance from Github, you also need the **devtools**
package.  This can be installed by typing the following code at the R
command line prompt:

```
install.packages('devtools')
```

## Installation

The most recent stable version of provenance is available from **CRAN** at
[https://cran.r-project.org/package=provenance](https://cran.r-project.org/package=provenance)
and can be installed on your system as follows:

```
install.packages('provenance')
```

Alternatively, to install the current development version of
provenance from Github, type:

```
library(devtools)
install_github('pvermees/provenance')
```

## Further information

See
[https://www.ucl.ac.uk/~ucfbpve/provenance/](https://www.ucl.ac.uk/~ucfbpve/provenance/)

[Vermeesch, P., Resentini, A. and Garzanti, E., 2016, An R package for
statistical provenance analysis, Sedimentary Geology, 336,
14-25](https://www.ucl.ac.uk/~ucfbpve/papers/VermeeschSedGeol2016/)

[Vermeesch, P., 2018, Statistical models for point-counting
data. Earth and Planetary Science Letters (in
press)](https://www.ucl.ac.uk/~ucfbpve/papers/VermeeschEPSL2018/)

## Author

[Pieter Vermeesch](https://www.ucl.ac.uk/~ucfbpve/)

## License

This project is licensed under the GPL-3 License

==> provenance_4.3.tar.gz: provenance/README.md <==
# provenance

**provenance** bundles a number of established statistical methods to
  facilitate the visual interpretation of large datasets in
  sedimentary geology. Includes functionality for adaptive kernel
  density estimation, principal component analysis, correspondence
  analysis, multidimensional scaling, generalised procrustes analysis
  and individual differences scaling using a variety of dissimilarity
  measures. Univariate provenance proxies, such as single-grain ages
  or (isotopic) compositions are compared with the Kolmogorov-Smirnov,
  Kuiper or Sircombe-Hazelton L2 distances. Categorical provenance
  proxies such as chemical compositions are compared with the
  Aitchison and Bray-Curtis distances, and point-counting data with
  the chi-square distance. Also included are tools to plot
  compositional and point-counting data on ternary diagrams and
  point-counting data on radial plots, to calculate the sample size
  required for specified levels of statistical precision, and to
  assess the effects of hydraulic sorting on detrital
  compositions. Includes an intuitive query-based user interface for
  users who are not proficient in R..

## Prerequisites

You must have **R** installed on your system (see
[https://www.r-project.org](https://www.r-project.org)).  Additionally, to
install provenance from Github, you also need the **devtools**
package.  This can be installed by typing the following code at the R
command line prompt:

```
install.packages('devtools')
```

## Installation

The most recent stable version of provenance is available from **CRAN** at
[https://cran.r-project.org/package=provenance](https://cran.r-project.org/package=provenance)
and can be installed on your system as follows:

```
install.packages('provenance')
```

Alternatively, to install the current development version of
provenance from Github, type:

```
library(devtools)
install_github('pvermees/provenance')
```

## Further information

See
[https://www.ucl.ac.uk/~ucfbpve/provenance/](https://www.ucl.ac.uk/~ucfbpve/provenance/)

[Vermeesch, P., Resentini, A. and Garzanti, E., 2016, An R package for
statistical provenance analysis, Sedimentary Geology, 336,
14-25](https://www.ucl.ac.uk/~ucfbpve/papers/VermeeschSedGeol2016/)

[Vermeesch, P., 2018, Statistical models for point-counting
data. Earth and Planetary Science Letters 501, 1-7](https://www.ucl.ac.uk/~ucfbpve/papers/VermeeschEPSL2018/)

## Author

[Pieter Vermeesch](https://www.ucl.ac.uk/~ucfbpve/)

## License

This project is licensed under the GPL-3 License
